@@ -639,6 +639,8 @@ def get_attribute_or_textop(obj,name):
         except AttributeError:
             if isinstance(obj,DictExt):
                 return NoAttr
+            elif isinstance(obj,(StrExt,UnicodeExt)):
+                raise
             def fn(*args,**kwargs):
                 return map(lambda s:getattr(str if isinstance(s,str) else unicode, name)(s,*args,**kwargs),obj)
 
@@ -997,3 +999,10 @@ def eformat(format_str,lst,dct,defvalue='-'):
         'unknown_tag_2 => unknown_tag_software : 32591 dowloads'
     """
     return vformat(format_str,DefaultList(defvalue,lst),DefaultDict(defvalue,dct))
+
+# NoAttr.as_list must return an empty ListExt() not a simple list
+# This customize noattr module for textops.
+from noattr import NoAttrType
+def _as_list(self):
+    return ListExt()
+NoAttrType.as_list=property(_as_list)
